@@ -3,4 +3,4 @@
 from .api import \
     parse, is_pattern, build, expand, match, get, has, update, remove, apply, \
     register, transform, assemble, ANY, is_inverted, get_multi, update_multi, \
-    remove_multi, match_multi
+    remove_multi, match_multi, quote
